#
# spec file for package monitoring-plugins-http_json
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname monitoring-plugins-http_json
%define skip_python36 1
%define skip_python38 1
%define skip_python39 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           monitoring-plugins-http_json
Version:        2.1.2
Release:        bp155.1.5
Summary:        Plugin for Nagios which checks json values from a given HTTP endpoint
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://github.com/drewkerrigan/nagios-http-json
Source:         https://github.com/drewkerrigan/nagios-http-json/archive/v%{version}.tar.gz#/nagios-http-json-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  nagios-rpm-macros
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
A generic plugin for Icinga/Nagios which checks json values from a given
HTTP endpoint against argument specified rules and determines the
status and performance data for that service.

%prep
%setup -q -n nagios-http-json-%{version}
sed -i -e '1{s:^#!\s*/usr/bin/env python:#!%{_bindir}/python:}' *.py

%build
/bin/true

%install
install -Dpm 0755 check_http_json.py %{buildroot}%{nagios_plugindir}/check_http_json

%check
# There are no tests upstream, don’t pretend there are.

%files %{python_files}
%license LICENSE
%doc README.md docs
%doc contrib/icinga2_check_command_definition.conf
%dir %{nagios_libdir}
%dir %{nagios_plugindir}
%{nagios_plugindir}/check_http_json

%changelog
* Fri Sep 16 2022 Martin Liška <mliska@suse.cz>
- Update to 2.1.2:
  * Fix missing type conversion for --data by @K0nne in #77
  * Add CLI Flag to change HTTP method by @martialblog in #79
  * Update Makefile and Workflows by @martialblog in #78
* Tue Mar  8 2022 Martin Liška <mliska@suse.cz>
-  Skip build for Python 3.8.
* Tue Mar  8 2022 Martin Liška <mliska@suse.cz>
-  Skip build for Python 3.6.
* Tue May  4 2021 Martin Hauke <mardnh@gmx.de>
- Skip build with python39
* Mon Mar  8 2021 Martin Hauke <mardnh@gmx.de>
- Don't use python_alternatives
* Tue Mar  2 2021 Martin Hauke <mardnh@gmx.de>
- Don't build with python36
- Update to version 2.1.1
  * Always load system default CA files.
  * Fix conditional check on empty data.
- Update to version 2.1
  * Empty JSON return values are now handled.
  * Scripts tries to parse and apply rules on HTTPErrors (50*)
- remove extra download of icinga2_check_command_definition.conf
  it's now part of the release tarball
* Fri Jul  3 2020 mliska@suse.cz
- Update to version 2.1+git.1593763135.c23ebac:
  * Add JSON parsing on HTTPError
  * Add handling of empty JSON return values
  * Add spaces to debug output
  * Add JSON parsing on HTTPError
  * Adjust pylint for new function
  * Move main entrypoint to own function for simpler testing
  * Add Makefile and requirements.txt for easier testing
  * Update README
  * added missing cli args for V2.0
  * added icinga2 command definitions
* Tue Mar 31 2020 Martin Hauke <mardnh@gmx.de>
- Add icinga2 command configuration template (not yet part of
  upstream)
* Tue Mar 31 2020 mcepl@cepl.eu
- Update to version 2.0+git.1585671306.219e993:
  * Code Refactor. UnitTests are now in a separate file and CI is enabled.
  * Python 3 support #48 #56
  * OK Results can now show the returned data #52
  * New CLI option -F to split JSON values #54
  * Various Bugfixes #34 #43 #53
* Tue Mar 24 2020 mcepl@cepl.eu
- Update to version 1.4+git.1580742414.2196dba:
- Branch python3 has been merged, pulling from the master.
- There are no tests upstream, don't pretend there are.
* Tue Mar 24 2020 Martin Liška <mliska@suse.cz>
- Remove update-alternatives and install to nagios plugin folder.
* Tue Mar 24 2020 Martin Liška <mliska@suse.cz>
- Rename to monitoring-plugins-http_json.
* Thu Mar 12 2020 mcepl@cepl.eu
- Update to version 1.4+git.1584019054.4f1d29d:
  * Fix new Python3.8 warnings:
* Tue Mar 10 2020 mcepl@cepl.eu
- Update to version 1.4+git.1583782740.e7cf7ca:
  * Add value_separator option to specify how JSON values are being split
  * Add boundary check for SubArrayElement function
  * Add unittest for argsparse
  * Add test case for key_value_list_unknown
  * Add and format some doc_strings
  * Use Python3 in GitHub Action
  * Add CI Badge to README
  * Add Coverage report
  * Add GitHub Action for Unit Test
  * Move test to separat file
* Tue Mar 10 2020 Matej Cepl <mcepl@suse.com>
- Initial packaging effort
